@@ -1,4 +1,4 @@
-def acot(x) -> float:
+def acot(x: float) -> float:
     """
     Return the arc cotangent (measured in radians) of x.
     """
