@@ -1,4 +1,4 @@
-def asin(x) -> float:
+def asin(x: float) -> float:
     """
     Return the arc sine (measured in radians) of x.
     """
@@ -13,5 +13,4 @@ def asin(x) -> float:
             def integrand(t):
                 return 1/(1-t**2)**.5
             return integrate(integrand, 0, x)
-    else:
-        raise ValueError("Value input must be in [-1 .. 1]")
+    raise ValueError("Value input must be in [-1 .. 1]")
