@@ -1,4 +1,4 @@
-def bin_rep(n) -> str:
+def bin_rep(n: float) -> str:
     """
     Return the binary representaion of n.
     """
