@@ -1,4 +1,4 @@
-def ceil(x) -> int:
+def ceil(x: float) -> int:
     """
     Return the ceiling of x, the smallest integer greater than or equal to x.
     """
