@@ -1,4 +1,4 @@
-def cos(x, deg=False) -> float | complex:
+def cos(x: float | complex, deg=False) -> float | complex:
     """
     Return the cosine of x.
 
