@@ -1,4 +1,4 @@
-def cosh(x) -> float | complex:
+def cosh(x: float | complex) -> float | complex:
     """
     Return the hyperbolic cosine of x.
     """
