@@ -1,4 +1,4 @@
-def coth(x) -> float | complex:
+def coth(x: float | complex) -> float | complex:
     """
     Return the hyperbolic cotangent of x.
     """
