@@ -1,4 +1,4 @@
-def csc(x, deg=False) -> float | complex:
+def csc(x: float | complex, deg=False) -> float | complex:
     """
     Return the cosecant of x.
 
