@@ -1,4 +1,4 @@
-def csch(x) -> float | complex:
+def csch(x: float | complex) -> float | complex:
     """
     Return the hyperbolic cosecant of x.
     """
