@@ -1,4 +1,4 @@
-def derivative(func, value) -> float | complex:
+def derivative(func: 'function', value: float | complex) -> float | complex:
     """
     Return the derivative of a function 'func' at a specific value.
     """
