@@ -1,4 +1,4 @@
-def exp(x) -> float | complex:
+def exp(x: float | complex) -> float | complex:
     """
     Return the exponential function of x.
     """
