@@ -1,4 +1,4 @@
-def floor(x) -> int:
+def floor(x: float) -> int:
     """
     Return the floor of x, the largest integer less than or equal to x.
     """
