@@ -1,18 +1,20 @@
-def integrate(integrand, lower_limit, upper_limit) -> float:
+def integrate(integrand, lower_limit: float, upper_limit: float) -> float:
     """
     Return the result of the integral of 'integrand' from 'lower_limit' to 'upper_limit'.
     """
+    n = 1000000
     if upper_limit == float('inf'):
-        upper_limit = 999999999999999
+        upper_limit = 500000
     if upper_limit == float('-inf'):
-        upper_limit = -999999999999999
+        upper_limit = -500000
     if lower_limit == float('inf'):
-        lower_limit = 999999999999999
+        lower_limit = 500000
     if lower_limit == float('-inf'):
-        lower_limit = -999999999999999
-    segment_width = (upper_limit - lower_limit) / 60000
+        lower_limit = -500000
+    
+    segment_width = (upper_limit - lower_limit) / n
     result = 0.5 * (integrand(lower_limit) + integrand(upper_limit))
-    for i in range(1,60000):
+    for i in range(1,n):
         x_i = lower_limit + i * segment_width
         result += integrand(x_i)
     result *= segment_width
