@@ -1,4 +1,4 @@
-def ln(x) -> float | complex:
+def ln(x: float) -> float | complex:
     """
     Return the natural logarithm of x.
     """
