@@ -1,4 +1,4 @@
-def quad(a,b,c) -> list:
+def quad(a:float | complex,b: float | complex,c: float | complex) -> list:
     """
     Return the solutions of the quadratic equation (form of: ax² + bx + c = 0).
     """
