@@ -1,4 +1,4 @@
-def radians(x) -> float:
+def radians(x:float) -> float:
     """
     Convert a value from the unit degrees to the unit radians.
     """
