@@ -1,4 +1,4 @@
-def sec(x, deg=False) -> float | complex:
+def sec(x:float | complex, deg=False) -> float | complex:
     """
     Return the secant of x.
 
