@@ -1,4 +1,4 @@
-def sech(x) -> float | complex:
+def sech(x: float | complex) -> float | complex:
     """
     Return the hyperbolic secant of x.
     """
