@@ -1,4 +1,4 @@
-def sin(x, deg=False) -> float | complex:
+def sin(x: float | complex, deg=False) -> float | complex:
     """
     Return the sine of x.
 
