@@ -1,4 +1,4 @@
-def sinh(x) -> float | complex:
+def sinh(x: float | complex) -> float | complex:
     """
     Return the hyperbolic sine of x.
     """
