@@ -1,4 +1,4 @@
-def sqrt(x) -> float | complex:
+def sqrt(x: float | complex) -> float | complex:
     """
     Return the square root of x.
     """
