@@ -1,4 +1,4 @@
-def tan(x, deg=False) -> float | complex:
+def tan(x: float | complex, deg=False) -> float | complex:
     """
     Return the tangent of x.
 
@@ -8,5 +8,5 @@ def tan(x, deg=False) -> float | complex:
     from .cos import cos
     from .constants import pi
     if deg:
-        x = pi(x/180)
+        x = pi*(x/180)
     return sin(x)/cos(x)
