@@ -1,4 +1,4 @@
-def tanh(x) -> float | complex:
+def tanh(x: float | complex) -> float | complex:
     """
     Return the hyperbolic tangent of x.
     """
